@@ -23,9 +23,9 @@
 #include "pdf-document.h"
 #include "ev-ps-exporter.h"
 #include "ev-document-find.h"
+#include "ev-document-misc.h"
 #include "gpdf-g-switch.h"
 #include "ev-document-links.h"
-#include "ev-document-misc.h"
 #include "ev-document-security.h"
 #include "ev-document-thumbnails.h"
 
@@ -90,7 +90,6 @@ struct _PdfDocument
 	UnicodeMap *umap;
 
 	gchar *password;
-	gboolean page_valid;
 
 	PdfDocumentSearch *search;
 };
@@ -136,10 +135,10 @@ document_init_links (PdfDocument *pdf_document)
 	obj.free ();
 }
 
-static gboolean
-document_validate_page (PdfDocument *pdf_document)
+static void
+document_display_page (PdfDocument *pdf_document)
 {
-	if (!pdf_document->page_valid) {
+	if (pdf_document->out != NULL) {
 		pdf_document->doc->displayPage (pdf_document->out, pdf_document->page,
 						72 * pdf_document->scale,
 						72 * pdf_document->scale,
@@ -147,18 +146,12 @@ document_validate_page (PdfDocument *pdf_document)
 
 		document_init_links (pdf_document);
 
-		pdf_document->page_valid = TRUE;
-
-		ev_document_changed (EV_DOCUMENT (pdf_document));
-
-                /* Update the search results available to the app since
-                 * we only provide full results on the current page
-                 */
-                if (pdf_document->search)
-                        pdf_document_search_page_changed (pdf_document->search);
+		/* Update the search results available to the app since
+		 * we only provide full results on the current page
+	         */
+		if (pdf_document->search)
+			pdf_document_search_page_changed (pdf_document->search);
 	}
-
-	return pdf_document->page_valid;
 }
 
 static gboolean
@@ -227,8 +220,6 @@ pdf_document_load (EvDocument  *document,
 	if (pdf_document->out)
 		pdf_document->out->startDoc(pdf_document->doc->getXRef());
 
-	pdf_document->page_valid = FALSE;
-
 	g_object_notify (G_OBJECT (pdf_document), "title");
 
 	return TRUE;
@@ -274,7 +265,8 @@ pdf_document_set_page (EvDocument  *document,
 
 	if (page != pdf_document->page) {
 		pdf_document->page = page;
-		pdf_document->page_valid = FALSE;
+		document_display_page (pdf_document);
+		ev_document_page_changed (EV_DOCUMENT (pdf_document));
 	}
 }
 
@@ -319,9 +311,8 @@ pdf_document_set_target (EvDocument  *document,
 			if (pdf_document->doc)
 				pdf_document->out->startDoc(pdf_document->doc->getXRef());
 
+			document_display_page (pdf_document);
 		}
-
-		pdf_document->page_valid = FALSE;
 	}
 }
 
@@ -333,7 +324,8 @@ pdf_document_set_scale (EvDocument  *document,
 
 	if (pdf_document->scale != scale) {
 		pdf_document->scale = scale;
-		pdf_document->page_valid = FALSE;
+		document_display_page (pdf_document);
+		ev_document_scale_changed (EV_DOCUMENT (pdf_document));
 	}
 }
 
@@ -348,6 +340,19 @@ pdf_document_set_page_offset (EvDocument  *document,
 	pdf_document->page_y_offset = y;
 }
 
+static gint
+canonical_multiple_of_90 (gint n)
+{
+	while (n >= 360) {
+		n -= 360;
+	}
+	while (n < 0) {
+		n += 360;
+	}
+
+	return 90 * (gint)((n / 90.0) + .5);
+}
+
 static void
 pdf_document_get_page_size (EvDocument   *document,
 			    int           page,
@@ -355,28 +360,30 @@ pdf_document_get_page_size (EvDocument   *document,
 			    int          *height)
 {
 	PdfDocument *pdf_document = PDF_DOCUMENT (document);
-	Page *the_page;
+	Page *doc_page;
+	int page_width = 1, page_height = 1;
+	double scale = pdf_document->scale;
 
-	/* set some default values */
-	if (width)
-		*width = 1;
-	if (height)
-		*height = 1;
+	if (page == -1) 
+		page = pdf_document->page;
 
-		
-	if (page == -1 && document_validate_page (pdf_document)) {
-		if (width)
-			*width = pdf_document->out->getBitmapWidth();
-		if (height)
-			*height = pdf_document->out->getBitmapHeight();
-		return;
+	doc_page = pdf_document->doc->getCatalog ()->getPage (page);
+
+	if (page) {
+		int page_rotate;
+
+		page_rotate = canonical_multiple_of_90 (doc_page->getRotate ());
+		if (page_rotate == 90 || page_rotate == 270) {
+			page_width = (int) ((doc_page->getHeight () * scale) + 0.5);
+			page_height = (int) ((doc_page->getWidth () * scale) + 0.5);
+		} else /* if (page_rotate == 0 || page_rotate == 180) */ {
+			page_width = (int) ((doc_page->getWidth () * scale) + 0.5);
+			page_height = (int) ((doc_page->getHeight () * scale) + 0.5);
+		}
 	}
 
-	the_page = pdf_document->doc->getCatalog ()->getPage (page);
-	if (the_page) {
-		*width = (int) the_page->getWidth ();
-		*height = (int) the_page->getHeight ();
-	}
+	if (width) *width = page_width;
+	if (height) *height = page_height;
 }
 
 static void
@@ -390,7 +397,7 @@ pdf_document_render (EvDocument  *document,
 	GdkRectangle page;
 	GdkRectangle draw;
 
-	if (!document_validate_page (pdf_document) || !pdf_document->target)
+	if (!pdf_document->target)
 		return;
 
 	page.x = pdf_document->page_x_offset;
@@ -492,12 +499,6 @@ pdf_document_search_page_changed (PdfDocumentSearch   *search)
 
         current_page = pdf_document->page;
 
-        if (!pdf_document->page_valid) {
-                /* we can't do anything until displayPage() */
-                search->current_page = -1;
-                return;
-        }
-
         if (search->current_page == current_page)
                 return;
 
@@ -812,9 +813,7 @@ build_link_from_action (PdfDocument *pdf_document,
 {
 	EvLink *link = NULL;
 
-	if (link_action == NULL) {
-		link = ev_link_new_title (title);
-	} else if (link_action->getKind () == actionGoToR) {
+	if (link_action->getKind () == actionGoToR) {
 		g_warning ("actionGoToR links not implemented");
 	} else if (link_action->getKind () == actionLaunch) {
 		g_warning ("actionLaunch links not implemented");
@@ -868,6 +867,10 @@ build_link_from_action (PdfDocument *pdf_document,
 			   link_unknown->getAction()->getCString());
 	}
 
+	if (link == NULL) {
+		link = ev_link_new_title (title);
+	}
+
 	return link;
 }
 
@@ -1050,10 +1053,10 @@ pdf_document_get_text (EvDocument *document, GdkRectangle *rect)
 	const char *text;
 	int x1, y1, x2, y2;
 
-	x1 = rect->x + pdf_document->page_x_offset;
-	y1 = rect->y + pdf_document->page_y_offset;
-	x2 = x1 + rect->width + pdf_document->page_x_offset;
-	y2 = y1 + rect->height + pdf_document->page_y_offset;
+	x1 = rect->x - pdf_document->page_x_offset;
+	y1 = rect->y - pdf_document->page_y_offset;
+	x2 = x1 + rect->width;
+	y2 = y1 + rect->height;
 
 	sel_text = pdf_document->out->getText (x1, y1, x2, y2);
 	text = sel_text->getCString ();
@@ -1369,7 +1372,6 @@ pdf_document_init (PdfDocument *pdf_document)
 	pdf_document->page_y_offset = 0;
 	pdf_document->scale = 1.;
 
-	pdf_document->page_valid = FALSE;
 	pdf_document->password = NULL;
 }
 
