@@ -228,6 +228,7 @@ do_one_iteration (EvSidebarThumbnails *ev_sidebar_thumbnails)
 		gtk_list_store_set (priv->list_store,
 				    &(priv->current_page_iter),
 				    COLUMN_PIXBUF, pixbuf,
+				    COLUMN_THUMBNAIL_SET, TRUE,
 				    -1);
 
 		g_object_unref (pixbuf);
@@ -312,6 +313,10 @@ ev_sidebar_thumbnails_select_page (EvSidebarThumbnails *sidebar,
 	GtkTreePath *path;
 	GtkTreeSelection *selection;
 
+	/* if the EvSidebar's document can't provide thumbnails */
+	if (sidebar->priv->document == NULL) 
+		return;
+
 	path = gtk_tree_path_new_from_indices (page - 1, -1);
 	selection = gtk_tree_view_get_selection
 			(GTK_TREE_VIEW (sidebar->priv->tree_view));
@@ -352,11 +357,11 @@ ev_sidebar_thumbnails_set_document (EvSidebarThumbnails *sidebar_thumbnails,
 	/* We get the dimensions of the first doc so that we can make a blank
 	 * icon.  */
 	ev_document_thumbnails_get_dimensions (EV_DOCUMENT_THUMBNAILS (priv->document),
-					       0, THUMBNAIL_WIDTH, &width, &height);
+					       1, THUMBNAIL_WIDTH, &width, &height);
 	loading_icon = ev_document_misc_get_thumbnail_frame (width, height, NULL);
 
-	for (i = 0; i < n_pages; i++) {
-		page = g_strdup_printf ("<i>%d</i>", i + 1);
+	for (i = 1; i <= n_pages; i++) {
+		page = g_strdup_printf ("<i>%d</i>", i);
 		gtk_list_store_append (priv->list_store, &iter);
 		gtk_list_store_set (priv->list_store, &iter,
 				    COLUMN_PAGE_STRING, page,
